@@ -9,3 +9,8 @@ val toString : t -> string
 val compare : t -> t -> int
 val eq : t -> t -> bool
 val hash : t -> int
+
+val normalize : t -> t
+
+val badEncoding : t -> bool
+val badFile : t -> bool
